@@ -2,7 +2,7 @@ import os
 import numpy as np
 import soundfile as sf
 import subprocess
-import glob
+from glob import glob
 import librosa
 
 EPS = np.finfo(float).eps
