@@ -315,10 +315,14 @@ def add_noise(audio_dir,noise_dir, cfg_filedir,louder=0,softer=0):
   noisy_scaled = noisy_scaled.astype(np.int16)
 
   #export file
-  if softer-louder > 0:
+  if softer-louder == 0:
+    #for no additional noise 
+    wf.write(f"{audio_dir.split('.wav')[0]}_noise_softer{softer}dB.wav", 16000, noisy_scaled)
+    wf.write(f"{audio_dir.split('.wav')[0]}_noise_louder{louder}dB.wav", 16000, noisy_scaled)
+  elif softer-louder > 0:
     wf.write(f"{audio_dir.split('.wav')[0]}_noise_softer{softer}dB.wav", 16000, noisy_scaled)
   else:
-    wf.write(f"{audio_dir.split('.wav')[0]}_noise_louder{softer}dB.wav", 16000, noisy_scaled)
+    wf.write(f"{audio_dir.split('.wav')[0]}_noise_louder{louder}dB.wav", 16000, noisy_scaled)
 
 def compare_phn_wrd_noise(timit_wav,
                           timit_phn, 
